#!/bin/bash
#

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}:${PRODUCTS}
}


# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
maketar=${2}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=hub
pkgver=v2_14_2
pkgdotver=`echo ${pkgver} | sed -e 's/_/./g'| sed -e 's/v//g'`
ssibuildshims_version=v1_04_14
pkgtarfile=${package}-v${pkgdotver}.tar 

get_this_dir
get_ssibuildshims

source define_basics NO_QUAL

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/bin ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL CURRENT
   exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

cd ${blddir}
tar xf ${product_dir}/${package}/${pkgver}/tar/${pkgtarfile} || ssi_die "failed to unwind ${pkgtarfile}"
set -x

cd ${blddir}/${package}-v${pkgdotver}
case $(ups flavor -1) in
  "Darwin64bit")
  URL="https://github.com/github/hub/releases/download/v${pkgdotver}/hub-darwin-amd64-${pkgdotver}.tgz"
  DLPKG=hub-darwin-amd64-${pkgdotver}
  ;;
  "Linux64bit")
  URL="https://github.com/github/hub/releases/download/v${pkgdotver}/hub-linux-amd64-${pkgdotver}.tgz"
  DLPKG=hub-linux-amd64-${pkgdotver}
  ;;
esac
curl -OL $URL
tar xf ${DLPKG}.tgz
rm -fv ${DLPKG}.tgz
cd ${DLPKG}
echo prefix=${pkgdir} ./install
prefix=${pkgdir} ./install
cd -
rm -rf ${DLPKG}
set +x

if [ ! -d ${pkgdir}/bin ]
then
   echo "ERROR: failed to create ${pkgdir}/bin"
   echo "       Something is very wrong"
   exit 1
fi


# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} NO_QUAL CURRENT

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -z ${product_dir} || ssi_die "setup failed"

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/bin ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL CURRENT
fi

exit 0
